@@ -1,8 +1,10 @@
 __title__ = 'tmuxp'
 __package_name__ = 'tmuxp'
-__version__ = '1.4.0'
+__version__ = '1.5.0'
 __description__ = 'tmux session manager'
 __email__ = 'tony@git-pull.com'
 __author__ = 'Tony Narlock'
+__github__ = 'https://github.com/tmux-python/tmuxp'
+__pypi__ = 'https://pypi.org/project/tmuxp/'
 __license__ = 'MIT'
-__copyright__ = 'Copyright 2013-2018 Tony Narlock'
+__copyright__ = 'Copyright 2013- Tony Narlock'
