@@ -5,7 +5,7 @@ tmuxp.cli
 ~~~~~~~~~
 
 """
-from __future__ import absolute_import, print_function, with_statement
+from __future__ import absolute_import
 
 import logging
 import os
@@ -14,50 +14,116 @@ import sys
 import click
 import kaptan
 from click.exceptions import FileError
-from libtmux.common import has_minimum_version, which, has_gte_version
+
+from libtmux.common import has_gte_version, has_minimum_version, which
 from libtmux.exc import TmuxCommandNotFound
 from libtmux.server import Server
 
-from . import WorkspaceBuilder, config, exc, log, util
+from . import config, exc, log, util
 from .__about__ import __version__
 from ._compat import string_types
-from .workspacebuilder import freeze
+from .workspacebuilder import WorkspaceBuilder, freeze
 
 logger = logging.getLogger(__name__)
 
 
-def get_config_dir():
-    if 'TMUXP_CONFIGDIR' in os.environ:
-        return os.path.expanduser(os.environ['TMUXP_CONFIGDIR'])
-
-    return os.path.expanduser('~/.tmuxp/')
-
-
 def get_cwd():
     return os.getcwd()
 
 
+def get_config_dir():
+    """
+    Return tmuxp configuration directory.
+
+    ``TMUXP_CONFIGDIR`` environmental variable has precedence if set. We also 
+    evaluate XDG default directory from XDG_CONFIG_HOME environmental variable 
+    if set or its default. Then the old default ~/.tmuxp is returned for 
+    compatibility.
+
+    Returns
+    -------
+    str :
+        absolute path to tmuxp config directory
+    """
+
+    paths = []
+    if 'TMUXP_CONFIGDIR' in os.environ:
+        paths.append(os.environ['TMUXP_CONFIGDIR'])
+    if 'XDG_CONFIG_HOME' in os.environ:
+        paths.append(os.environ['XDG_CONFIG_HOME'])
+    else:
+        paths.append('~/.config/tmuxp/')
+    paths.append('~/.tmuxp')
+
+    for path in paths:
+        path = os.path.expanduser(path)
+        if os.path.isdir(path):
+            return path
+    # Return last path as default if none of the previous ones matched
+    return path
+
+
 def get_tmuxinator_dir():
+    """
+    Return tmuxinator configuration directory.
+
+    Checks for ``TMUXINATOR_CONFIG`` environmental variable.
+
+    Returns
+    -------
+    str :
+        absolute path to tmuxinator config directory
+
+    See Also
+    --------
+    :meth:`tmuxp.config.import_tmuxinator`
+    """
+    if 'TMUXINATOR_CONFIG' in os.environ:
+        return os.path.expanduser(os.environ['TMUXINATOR_CONFIG'])
+
     return os.path.expanduser('~/.tmuxinator/')
 
 
 def get_teamocil_dir():
+    """
+    Return teamocil configuration directory.
+
+    Returns
+    -------
+    str :
+        absolute path to teamocil config directory
+
+    See Also
+    --------
+    :meth:`tmuxp.config.import_teamocil`
+    """
     return os.path.expanduser('~/.teamocil/')
 
 
 def _validate_choices(options):
-    """Callback wrapper for validating click.prompt input.
+    """
+    Callback wrapper for validating click.prompt input.
 
-    :param options: List of allowed choices
-    :type options: list
-    :rtype: func
-    :returns: function for value_proc in :func:`click.prompt`.
+    Parameters
+    ----------
+    options : list
+        List of allowed choices
+
+    Returns
+    -------
+    :func:`callable`
+        callback function for value_proc in :func:`click.prompt`.
+
+    Raises
+    ------
+    :class:`click.BadParameter`
     """
 
     def func(value):
         if value not in options:
             raise click.BadParameter(
-                'Possible choices are: {0}.'.format(', '.join(options)))
+                'Possible choices are: {0}.'.format(', '.join(options))
+            )
         return value
 
     return func
@@ -87,16 +153,14 @@ def set_layout_hook(session, hook_name):
 
     Also, the hooks are set immediately unbind after they're invoked via -u.
 
-    :param session: session to bind hook to
-    :type session: :class:`libtmux.session.Session`
-    :param hook_name: hook name to bind to, e.g. 'client-attached'
-    :type hook_name: str
+    Parameters
+    ----------
+    session : :class:`libtmux.session.Session`
+        session to bind hook to
+    hook_name : str
+        hook name to bind to, e.g. 'client-attached'
     """
-    cmd = [
-        'set-hook',
-        '-t', session.id,
-        hook_name
-    ]
+    cmd = ['set-hook', '-t', session.id, hook_name]
     hook_cmd = []
     for window in session.windows:
         # unfortunately, select-layout won't work unless
@@ -110,8 +174,7 @@ def set_layout_hook(session, hook_name):
     # unset the hook immediately after executing
     hook_cmd.append(
         'set-hook -u -t {target_session} {hook_name}'.format(
-            target_session=session.id,
-            hook_name=hook_name
+            target_session=session.id, hook_name=hook_name
         )
     )
 
@@ -126,21 +189,40 @@ def set_layout_hook(session, hook_name):
 
 
 def is_pure_name(path):
-    """Return True if path is a name and not a file path."""
+    """
+    Return True if path is a name and not a file path.
+
+    Parameters
+    ----------
+    path : str
+        Path (can be absolute, relative, etc.)
+
+    Returns
+    -------
+    bool
+        True if path is a name of config in config dir, not file path.
+    """
     return (
-        not os.path.isabs(path) and
-        len(os.path.dirname(path)) == 0 and
-        not os.path.splitext(path)[1] and
-        path != '.' and path != ''
+        not os.path.isabs(path)
+        and len(os.path.dirname(path)) == 0
+        and not os.path.splitext(path)[1]
+        and path != '.'
+        and path != ''
     )
 
 
-def _create_scan_config_argument(config_dir):
-    """For finding configurations in tmuxinator/teamocil"""
-    def func(ctx, param, value):
-        return scan_config_argument(ctx, param, value, config_dir)
+class ConfigPath(click.Path):
+    def __init__(self, config_dir=None, *args, **kwargs):
+        super(ConfigPath, self).__init__(*args, **kwargs)
+        self.config_dir = config_dir
 
-    return func
+    def convert(self, value, param, ctx):
+        config_dir = self.config_dir
+        if callable(config_dir):
+            config_dir = config_dir()
+
+        value = scan_config(value, config_dir=config_dir)
+        return super(ConfigPath, self).convert(value, param, ctx)
 
 
 def scan_config_argument(ctx, param, value, config_dir=None):
@@ -159,8 +241,7 @@ def scan_config_argument(ctx, param, value, config_dir=None):
         value = scan_config(value, config_dir=config_dir)
 
     elif isinstance(value, tuple):
-        value = tuple(
-            [scan_config(v, config_dir=config_dir) for v in value])
+        value = tuple([scan_config(v, config_dir=config_dir) for v in value])
 
     return value
 
@@ -181,19 +262,13 @@ def get_abs_path(config):
 def _resolve_path_no_overwrite(config):
     path = get_abs_path(config)
     if os.path.exists(path):
-        raise click.exceptions.UsageError(
-            '%s exists. Pick a new filename.' % path)
+        raise click.exceptions.UsageError('%s exists. Pick a new filename.' % path)
     return path
 
 
 def scan_config(config, config_dir=None):
-    """Return the real config path or raise an exception.
-
-    :param config: config file, valid examples:
-        - a file name, myconfig.yaml
-        - relative path, ../config.yaml or ../project
-        - a period, .
-    :type config: str
+    """
+    Return the real config path or raise an exception.
 
     If config is directory, scan for .tmuxp.{yaml,yml,json} in directory. If
     one or more found, it will warn and pick the first.
@@ -207,7 +282,18 @@ def scan_config(config, config_dir=None):
     it will scan for file name with yaml, yml and json. If multiple exist, it
     will warn and pick the first.
 
-    :raises: :class:`click.exceptions.FileError`
+    Parameters
+    ----------
+    config : str
+        config file, valid examples:
+
+        - a file name, myconfig.yaml
+        - relative path, ../config.yaml or ../project
+        - a period, .
+
+    Raises
+    ------
+    :class:`click.exceptions.FileError`
     """
     if not config_dir:
         config_dir = get_config_dir()
@@ -223,8 +309,11 @@ def scan_config(config, config_dir=None):
     if is_pure_name(config):
         is_name = True
     elif (
-        not isabs(config) or len(dirname(config)) > 1 or config == '.' or
-        config == "" or config == "./"
+        not isabs(config)
+        or len(dirname(config)) > 1
+        or config == '.'
+        or config == ""
+        or config == "./"
     ):  # if relative, fill in full path
         config = normpath(join(cwd, config))
 
@@ -232,31 +321,40 @@ def scan_config(config, config_dir=None):
     if not splitext(config)[1]:
         if is_name:
             candidates = [
-                x for x in ['%s%s' % (join(config_dir, config), ext)
-                            for ext in ['.yaml', '.yml', '.json']
-                            ] if exists(x)
+                x
+                for x in [
+                    '%s%s' % (join(config_dir, config), ext)
+                    for ext in ['.yaml', '.yml', '.json']
+                ]
+                if exists(x)
             ]
             if not len(candidates):
                 file_error = (
                     'config not found in config dir (yaml/yml/json) %s '
-                    'for name' % (config_dir))
+                    'for name' % (config_dir)
+                )
         else:
             candidates = [
-                x for x in [
-                    join(config, ext) for ext in
-                    ['.tmuxp.yaml', '.tmuxp.yml', '.tmuxp.json']
-                ] if exists(x)
+                x
+                for x in [
+                    join(config, ext)
+                    for ext in ['.tmuxp.yaml', '.tmuxp.yml', '.tmuxp.json']
+                ]
+                if exists(x)
             ]
 
             if len(candidates) > 1:
                 click.secho(
-                    'Multiple .tmuxp.{yml,yaml,json} configs in %s' %
-                    dirname(config), fg="red")
-                click.echo(click.wrap_text(
-                    'This is undefined behavior, use only one. '
-                    'Use file names e.g. myproject.json, coolproject.yaml. '
-                    'You can load them by filename.'
-                ))
+                    'Multiple .tmuxp.{yml,yaml,json} configs in %s' % dirname(config),
+                    fg="red",
+                )
+                click.echo(
+                    click.wrap_text(
+                        'This is undefined behavior, use only one. '
+                        'Use file names e.g. myproject.json, coolproject.yaml. '
+                        'You can load them by filename.'
+                    )
+                )
             elif not len(candidates):
                 file_error = 'No tmuxp files found in directory'
         if len(candidates):
@@ -270,77 +368,184 @@ def scan_config(config, config_dir=None):
     return config
 
 
+def _reattach(session):
+    """
+    Reattach session (depending on env being inside tmux already or not)
+
+    Parameters
+    ----------
+    session : :class:`libtmux.Session`
+
+    Notes
+    -----
+    If ``TMUX`` environmental variable exists in the environment this script is
+    running, that means we're in a tmux client. So ``tmux switch-client`` will
+    load the session.
+
+    If not, ``tmux attach-session`` loads the client to the target session.
+    """
+    if 'TMUX' in os.environ:
+        session.switch_client()
+
+    else:
+        session.attach_session()
+
+
 def load_workspace(
-    config_file, socket_name=None, socket_path=None, colors=None,
-    attached=None, detached=None, answer_yes=False
+    config_file,
+    socket_name=None,
+    socket_path=None,
+    colors=None,
+    detached=False,
+    answer_yes=False,
 ):
-    """Build config workspace.
+    """
+    Load a tmux "workspace" session via tmuxp file.
 
-    :param config_file: full path to config file
-    :param type: str
+    Parameters
+    ----------
+    config_file : str
+        absolute path to config file
+    socket_name : str, optional
+        ``tmux -L <socket-name>``
+    socket_path: str, optional
+        ``tmux -S <socket-path>``
+    colors : str, optional
+        '-2'
+            Force tmux to support 256 colors
+    detached : bool
+        Force detached state. default False.
+    answer_yes : bool
+        Assume yes when given prompt. default False.
 
+    Notes
+    -----
+
+    tmuxp will check and load a configuration file. The file will use kaptan
+    to load a JSON/YAML into a :py:obj:`dict`. Then :func:`config.expand` and
+    :func:`config.trickle` will be used to expand any shorthands, template
+    variables, or file paths relative to where the config/script is executed
+    from.
+
+    :func:`config.expand` accepts the directory of the config file, so the
+    user's configuration can resolve absolute paths relative to where the
+    config file is. In otherwords, if a config file at */var/moo/hi.yaml*
+    has *./* in its configs, we want to be sure any file path with *./* is
+    relative to */var/moo*, not the user's PWD.
+
+    A :class:`libtmux.Server` object is created. No tmux server is started yet,
+    just the object.
+
+    The prepared configuration and the server object is passed into an instance
+    of :class:`~tmuxp.workspacebuilder.WorkspaceBuilder`.
+
+    A sanity check against :meth:`libtmux.common.which` is ran. It will raise
+    an exception if tmux isn't found.
+
+    If a tmux session under the same name as ``session_name`` in the tmuxp
+    configuration exists, tmuxp offers to attach the session. Currently, tmuxp
+    does not allow appending a workspace / incremental building on top of a
+    current session (pull requests are welcome!).
+
+    :meth:`~tmuxp.workspacebuilder.WorkspaceBuilder.build` will build the session in
+    the background via using tmux's detached state (``-d``).
+
+    After the session (workspace) is built, unless the user decided to load
+    the session in the background via ``tmuxp -d`` (which is in the spirit
+    of tmux's ``-d``), we need to prompt the user to attach the session.
+
+    If the user is already inside a tmux client, which we detect via the
+    ``TMUX`` environment variable bring present, we will prompt the user to
+    switch their current client to it.
+
+    If they're outside of tmux client - in a plain-old PTY - we will
+    automatically ``attach``.
+
+    If an exception is raised during the building of the workspace, tmuxp will
+    prompt to cleanup (``$ tmux kill-session``) the session on the user's
+    behalf. An exception raised during this process means it's not easy to
+    predict how broken the session is.
+
+    .. versionchanged:: tmux 2.6+
+
+        In tmux 2.6, the way layout and proportion's work when interfacing
+        with tmux in a detached state (outside of a client) changed. Since
+        tmuxp builds workspaces in a detached state, the WorkspaceBuilder isn't
+        able to rely on functionality requiring awarness of session geometry,
+        e.g. ``set-layout``.
+
+        Thankfully, tmux is able to defer commands to run after the user
+        performs certain actions, such as loading a client via
+        ``attach-session`` or ``switch-client``.
+
+        Upon client switch, ``client-session-changed`` is triggered [1]_.
+
+    References
+    ----------
+    .. [1] cmd-switch-client.c hook. GitHub repo for tmux.
+       https://github.com/tmux/tmux/blob/2.6/cmd-switch-client.c#L132.
+       Accessed April 8th, 2018.
     """
     # get the canonical path, eliminating any symlinks
     config_file = os.path.realpath(config_file)
 
+    # kaptan allows us to open a yaml or json file as a dict
     sconfig = kaptan.Kaptan()
     sconfig = sconfig.import_config(config_file).get()
-    # expands configurations relative to config / profile file location
+    # shapes configurations relative to config / profile file location
     sconfig = config.expand(sconfig, os.path.dirname(config_file))
+    # propagate config inheritance (e.g. session -> window, window -> pane)
     sconfig = config.trickle(sconfig)
 
-    t = Server(
-        socket_name=socket_name,
-        socket_path=socket_path,
-        colors=colors
+    t = Server(  # create tmux server object
+        socket_name=socket_name, socket_path=socket_path, colors=colors
     )
 
-    try:
+    which('tmux')  # raise exception if tmux not found
+
+    try:  # load WorkspaceBuilder object for tmuxp config / tmux server
         builder = WorkspaceBuilder(sconf=sconfig, server=t)
     except exc.EmptyConfigException:
-        click.echo('%s is empty or parsed no config data' %
-                   config_file, err=True)
+        click.echo('%s is empty or parsed no config data' % config_file, err=True)
         return
 
-    which('tmux')
-
-    def reattach(session):
-        if 'TMUX' in os.environ:
-            session.switch_client()
-
-        else:
-            session.attach_session()
-
     session_name = sconfig['session_name']
+
+    # if the session already exists, prompt the user to attach. tmuxp doesn't
+    # support incremental session building or appending (yet, PR's welcome!)
     if builder.session_exists(session_name):
         if not detached and (
-            answer_yes or click.confirm(
-                '%s is already running. Attach?' %
-                click.style(session_name, fg='green'), default=True)
+            answer_yes
+            or click.confirm(
+                '%s is already running. Attach?'
+                % click.style(session_name, fg='green'),
+                default=True,
+            )
         ):
-            reattach(builder.session)
+            _reattach(builder.session)
         return
 
     try:
         click.echo(
-            click.style('[Loading] ', fg='green') +
-            click.style(config_file, fg='blue', bold=True))
-        builder.build()
+            click.style('[Loading] ', fg='green')
+            + click.style(config_file, fg='blue', bold=True)
+        )
+
+        builder.build()  # load tmux session via workspace builder
 
         if 'TMUX' in os.environ:  # tmuxp ran from inside tmux
-            if not detached and (answer_yes or click.confirm(
-                'Already inside TMUX, switch to session?'
-            )):
+            if not detached and (
+                answer_yes or click.confirm('Already inside TMUX, switch to session?')
+            ):
+                # unset TMUX, save it, e.g. '/tmp/tmux-1000/default,30668,0'
                 tmux_env = os.environ.pop('TMUX')
 
                 if has_gte_version('2.6'):
-                    # if using -d from inside tmux session + switching inside
-                    # https://github.com/tmux/tmux/blob/2.6/cmd-switch-client.c#L132
                     set_layout_hook(builder.session, 'client-session-changed')
 
-                builder.session.switch_client()
+                builder.session.switch_client()  # switch client to new session
 
-                os.environ['TMUX'] = tmux_env
+                os.environ['TMUX'] = tmux_env  # set TMUX back again
                 return builder.session
             else:  # session created in the background, from within tmux
                 if has_gte_version('2.6'):  # prepare for both cases
@@ -348,18 +553,16 @@ def load_workspace(
                     set_layout_hook(builder.session, 'client-session-changed')
 
                 sys.exit('Session created in detached state.')
+        else:  # tmuxp ran from inside tmux
+            if has_gte_version('2.6'):
+                # if attaching for first time
+                set_layout_hook(builder.session, 'client-attached')
 
-        # below: tmuxp ran outside of tmux
+                # for cases where user switches client for first time
+                set_layout_hook(builder.session, 'client-session-changed')
 
-        if has_gte_version('2.6'):
-            # if attaching for first time
-            set_layout_hook(builder.session, 'client-attached')
-
-            # for cases where user switches client for first time
-            set_layout_hook(builder.session, 'client-session-changed')
-
-        if not detached:
-            builder.session.attach_session()
+            if not detached:
+                builder.session.attach_session()
 
     except exc.TmuxpException as e:
         import traceback
@@ -370,7 +573,7 @@ def load_workspace(
         choice = click.prompt(
             'Error loading workspace. (k)ill, (a)ttach, (d)etach?',
             value_proc=_validate_choices(['k', 'a', 'd']),
-            default='k'
+            default='k',
         )
 
         if choice == 'k':
@@ -388,11 +591,12 @@ def load_workspace(
 
 
 @click.group(context_settings={'obj': {}})
-@click.version_option(
-    __version__, '-V', '--version', message='%(prog)s %(version)s'
+@click.version_option(__version__, '-V', '--version', message='%(prog)s %(version)s')
+@click.option(
+    '--log_level',
+    default='INFO',
+    help='Log level (DEBUG, INFO, WARNING, ERROR, CRITICAL)',
 )
-@click.option('--log_level', default='INFO',
-              help='Log level (DEBUG, INFO, WARNING, ERROR, CRITICAL)')
 def cli(log_level):
     """Manage tmux sessions.
 
@@ -407,21 +611,25 @@ def cli(log_level):
     except exc.TmuxpException as e:
         click.echo(e, err=True)
         sys.exit()
-    setup_logger(
-        level=log_level.upper()
-    )
+    setup_logger(level=log_level.upper())
 
 
 def setup_logger(logger=None, level='INFO'):
-    """Setup logging for CLI use.
-
-    :param logger: instance of logger
-    :type logger: :py:class:`Logger`
-
     """
-    if not logger:
+    Setup logging for CLI use.
+
+    Tries to do some conditionals to prevent handlers from being added twice.
+    Just to be safe.
+
+    Parameters
+    ----------
+    logger : :py:class:`Logger`
+        logger instance for tmuxp
+    """
+    if not logger:  # if no logger exists, make one
         logger = logging.getLogger()
-    if not logger.handlers:
+
+    if not logger.handlers:  # setup logger handlers
         channel = logging.StreamHandler()
         channel.setFormatter(log.DebugLogFormatter())
 
@@ -431,11 +639,12 @@ def setup_logger(logger=None, level='INFO'):
 
 
 def startup(config_dir):
-    """Initialize CLI.
-
-    :param get_config_dir(): Config directory to search
-    :type get_config_dir(): string
+    """
+    Initialize CLI.
 
+    Parameters
+    ----------
+    str : get_config_dir(): Config directory to search
     """
 
     if not os.path.exists(config_dir):
@@ -444,7 +653,7 @@ def startup(config_dir):
 
 @cli.command(name='freeze')
 @click.argument('session_name', nargs=1)
-@click.option('-S', 'socket_path', help='pass-through for tmux -L')
+@click.option('-S', 'socket_path', help='pass-through for tmux -S')
 @click.option('-L', 'socket_name', help='pass-through for tmux -L')
 def command_freeze(session_name, socket_name, socket_path):
     """Snapshot a session into a config.
@@ -452,15 +661,10 @@ def command_freeze(session_name, socket_name, socket_path):
     If SESSION_NAME is provided, snapshot that session. Otherwise, use the
     current session."""
 
-    t = Server(
-        socket_name=socket_name,
-        socket_path=socket_path,
-    )
+    t = Server(socket_name=socket_name, socket_path=socket_path)
 
     try:
-        session = t.find_where({
-            'session_name': session_name
-        })
+        session = t.find_where({'session_name': session_name})
 
         if not session:
             raise exc.TmuxpException('Session not found.')
@@ -473,9 +677,7 @@ def command_freeze(session_name, socket_name, socket_path):
     newconfig = config.inline(sconf)
     configparser.import_config(newconfig)
     config_format = click.prompt(
-        'Convert to',
-        value_proc=_validate_choices(['yaml', 'json']),
-        default='yaml'
+        'Convert to', value_proc=_validate_choices(['yaml', 'json']), default='yaml'
     )
 
     if config_format == 'yaml':
@@ -501,13 +703,15 @@ def command_freeze(session_name, socket_name, socket_path):
             save_to = os.path.abspath(
                 os.path.join(
                     get_config_dir(),
-                    '%s.%s' % (sconf.get('session_name'), config_format)
+                    '%s.%s' % (sconf.get('session_name'), config_format),
                 )
             )
             dest_prompt = click.prompt(
-                'Save to: %s' %
-                save_to, value_proc=get_abs_path,
-                default=save_to, confirmation_prompt=True)
+                'Save to: %s' % save_to,
+                value_proc=get_abs_path,
+                default=save_to,
+                confirmation_prompt=True,
+            )
             if os.path.exists(dest_prompt):
                 print('%s exists. Pick a new filename.' % dest_prompt)
                 continue
@@ -535,21 +739,27 @@ def command_freeze(session_name, socket_name, socket_path):
 
 @cli.command(name='load', short_help='Load tmuxp workspaces.')
 @click.pass_context
-@click.argument('config', click.Path(exists=True), nargs=-1,
-                callback=scan_config_argument)
-@click.option('-S', 'socket_path', help='pass-through for tmux -L')
+@click.argument('config', type=ConfigPath(exists=True), nargs=-1)
+@click.option('-S', 'socket_path', help='pass-through for tmux -S')
 @click.option('-L', 'socket_name', help='pass-through for tmux -L')
 @click.option('--yes', '-y', 'answer_yes', help='yes', is_flag=True)
-@click.option('-d', 'detached',
-              help='Load the session without attaching it', is_flag=True)
 @click.option(
-    '-2', 'colors', flag_value=256, default=True,
-    help='Force tmux to assume the terminal supports 256 colours.')
+    '-d', 'detached', help='Load the session without attaching it', is_flag=True
+)
 @click.option(
-    '-8', 'colors', flag_value=88,
-    help='Like -2, but indicates that the terminal supports 88 colours.')
-def command_load(ctx, config, socket_name, socket_path, answer_yes,
-                 detached, colors):
+    'colors',
+    '-2',
+    flag_value=256,
+    default=True,
+    help='Force tmux to assume the terminal supports 256 colours.',
+)
+@click.option(
+    'colors',
+    '-8',
+    flag_value=88,
+    help='Like -2, but indicates that the terminal supports 88 colours.',
+)
+def command_load(ctx, config, socket_name, socket_path, answer_yes, detached, colors):
     """Load a tmux workspace from each CONFIG.
 
     CONFIG is a specifier for a configuration file.
@@ -579,7 +789,7 @@ def command_load(ctx, config, socket_name, socket_path, answer_yes,
         'socket_path': socket_path,
         'answer_yes': answer_yes,
         'colors': colors,
-        'detached': detached
+        'detached': detached,
     }
 
     if not config:
@@ -616,23 +826,18 @@ def import_config(configfile, importfunc):
     configparser.import_config(newconfig)
 
     config_format = click.prompt(
-        'Convert to',
-        value_proc=_validate_choices(['yaml', 'json']),
-        default='yaml'
+        'Convert to', value_proc=_validate_choices(['yaml', 'json']), default='yaml'
     )
 
     if config_format == 'yaml':
-        newconfig = configparser.export(
-            'yaml', indent=2, default_flow_style=False
-        )
+        newconfig = configparser.export('yaml', indent=2, default_flow_style=False)
     elif config_format == 'json':
         newconfig = configparser.export('json', indent=2)
     else:
         sys.exit('Unknown config format.')
 
     click.echo(
-        newconfig +
-        '---------------------------------------------------------------'
+        newconfig + '---------------------------------------------------------------'
         '\n'
         'Configuration import does its best to convert files.\n'
     )
@@ -642,8 +847,8 @@ def import_config(configfile, importfunc):
         dest = None
         while not dest:
             dest_path = click.prompt(
-                'Save to [%s]' % os.getcwd(),
-                value_proc=_resolve_path_no_overwrite,)
+                'Save to [%s]' % os.getcwd(), value_proc=_resolve_path_no_overwrite
+            )
 
             # dest = dest_prompt
             if click.confirm('Save to %s?' % dest_path):
@@ -663,11 +868,11 @@ def import_config(configfile, importfunc):
         sys.exit()
 
 
-@import_config_cmd.command(name='teamocil',
-                           short_help='Convert and import a teamocil config.')
+@import_config_cmd.command(
+    name='teamocil', short_help='Convert and import a teamocil config.'
+)
 @click.argument(
-    'configfile', click.Path(exists=True), nargs=1,
-    callback=_create_scan_config_argument(get_teamocil_dir)
+    'configfile', type=ConfigPath(exists=True, config_dir=get_teamocil_dir), nargs=1
 )
 def command_import_teamocil(configfile):
     """Convert a teamocil config from CONFIGFILE to tmuxp format and import
@@ -677,11 +882,10 @@ def command_import_teamocil(configfile):
 
 
 @import_config_cmd.command(
-    name='tmuxinator',
-    short_help='Convert and import a tmuxinator config.')
+    name='tmuxinator', short_help='Convert and import a tmuxinator config.'
+)
 @click.argument(
-    'configfile', click.Path(exists=True), nargs=1,
-    callback=_create_scan_config_argument(get_tmuxinator_dir)
+    'configfile', type=ConfigPath(exists=True, config_dir=get_tmuxinator_dir), nargs=1
 )
 def command_import_tmuxinator(configfile):
     """Convert a tmuxinator config from CONFIGFILE to tmuxp format and import
@@ -690,41 +894,30 @@ def command_import_tmuxinator(configfile):
 
 
 @cli.command(name='convert')
-@click.argument('config', click.Path(exists=True), nargs=1,
-                callback=scan_config_argument)
+@click.argument('config', type=ConfigPath(exists=True), nargs=1)
 def command_convert(config):
     """Convert a tmuxp config between JSON and YAML."""
 
     _, ext = os.path.splitext(config)
     if 'json' in ext:
-        if click.confirm(
-            'convert to <%s> to yaml?' % config
-        ):
+        if click.confirm('convert to <%s> to yaml?' % config):
             configparser = kaptan.Kaptan()
             configparser.import_config(config)
             newfile = config.replace(ext, '.yaml')
-            newconfig = configparser.export(
-                'yaml', indent=2, default_flow_style=False
-            )
-            if click.confirm(
-                'Save config to %s?' % newfile
-            ):
+            newconfig = configparser.export('yaml', indent=2, default_flow_style=False)
+            if click.confirm('Save config to %s?' % newfile):
                 buf = open(newfile, 'w')
                 buf.write(newconfig)
                 buf.close()
                 print('New config saved to %s' % newfile)
     elif 'yaml' in ext:
-        if click.confirm(
-            'convert to <%s> to json?' % config
-        ):
+        if click.confirm('convert to <%s> to json?' % config):
             configparser = kaptan.Kaptan()
             configparser.import_config(config)
             newfile = config.replace(ext, '.json')
             newconfig = configparser.export('json', indent=2)
             print(newconfig)
-            if click.confirm(
-                'Save config to <%s>?' % newfile
-            ):
+            if click.confirm('Save config to <%s>?' % newfile):
                 buf = open(newfile, 'w')
                 buf.write(newconfig)
                 buf.close()
